Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(85)

Unified Diff: chrome/browser/system_monitor/removable_device_notifications_linux.cc

Issue 10933114: Combine boolean MediaDeviceNotifications histograms to an enumerated histogram. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Addressed comments Created 8 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/system_monitor/removable_device_notifications_linux.cc
diff --git a/chrome/browser/system_monitor/removable_device_notifications_linux.cc b/chrome/browser/system_monitor/removable_device_notifications_linux.cc
index 2d484dc9d7721c2a47e4dc6393829fe7e89b313d..c6b56de239b305b69fe641893471c719c515e05f 100644
--- a/chrome/browser/system_monitor/removable_device_notifications_linux.cc
+++ b/chrome/browser/system_monitor/removable_device_notifications_linux.cc
@@ -435,12 +435,8 @@ void RemovableDeviceNotificationsLinux::AddNewMount(
bool removable;
get_device_info_func_(mount_device, &unique_id, &name, &removable);
-
- // Keep track of device uuid, to see how often we receive empty values.
- UMA_HISTOGRAM_BOOLEAN("MediaDeviceNotification.DeviceUUIDAvailable",
- !unique_id.empty());
- UMA_HISTOGRAM_BOOLEAN("MediaDeviceNotification.DeviceNameAvailable",
- !name.empty());
+ // Keep track of device info details to see how often we get invalid values.
+ MediaStorageUtil::RecordDeviceInfoHistogram(true, unique_id, name);
if (unique_id.empty() || name.empty())
return;

Powered by Google App Engine
This is Rietveld 408576698